@@ -5,13 +5,13 @@ from questions_three.exceptions import UndefinedEvent
 
 from .event_broker import EventBroker
 
-EVENT_HANDLER_PATTERN = re.compile('^on_(.+)$')
+EVENT_HANDLER_PATTERN = re.compile("^on_(.+)$")
 
 
 def event_for_handler(handler_name):
     mat = EVENT_HANDLER_PATTERN.search(handler_name)
     if not mat:
-        raise RuntimeError('Failed to parse %s' % handler_name)
+        raise RuntimeError("Failed to parse %s" % handler_name)
     event = mat.group(1)
     if event in [e.name for e in TestEvent]:
         return TestEvent[mat.group(1)]
@@ -19,7 +19,7 @@ def event_for_handler(handler_name):
 
 
 def event_handler_names(obj):
-    return [name for name in dir(obj) if name.startswith('on_')]
+    return [name for name in dir(obj) if name.startswith("on_")]
 
 
 def subscribe_event_handlers(obj):
@@ -28,7 +28,5 @@ def subscribe_event_handlers(obj):
     """
     for func_name in event_handler_names(obj):
         attr = getattr(obj, func_name)
-        if hasattr(attr, '__call__'):
-            EventBroker.subscribe(
-                event=event_for_handler(func_name),
-                func=getattr(obj, func_name))
+        if hasattr(attr, "__call__"):
+            EventBroker.subscribe(event=event_for_handler(func_name), func=getattr(obj, func_name))
