@@ -5,17 +5,18 @@ from twin_sister import dependency
 
 
 class OperationFailed(RuntimeError):
-
     def errors_to_string(self):
-        error_messages = list(filter(None, [error['message'] if 'message' in error else None for error in self.errors]))
-        if error_messages == [''] or error_messages == []:
-            return f'Operation Failed: {self.errors}'
+        error_messages = list(
+            filter(None, [error["message"] if "message" in error else None for error in self.errors])
+        )
+        if error_messages == [""] or error_messages == []:
+            return f"Operation Failed: {self.errors}"
         else:
-            return f'Operation Failed: {error_messages}'
+            return f"Operation Failed: {error_messages}"
 
     def __init__(self, *args, requests_response=None):
         if not isinstance(requests_response, requests.Response):
-            raise TypeError('Refusing to work until given a requests.Response object')
+            raise TypeError("Refusing to work until given a requests.Response object")
         self.http_response = requests_response
         all_args = args + (self.errors_to_string(),)
         dependency(super)().__init__(*all_args)
@@ -25,19 +26,19 @@ class OperationFailed(RuntimeError):
 
     @property
     def operation(self):
-        return self._request_body()['query']
+        return self._request_body()["query"]
 
     @property
     def operation_variables(self):
-        return self._request_body()['variables']
+        return self._request_body()["variables"]
 
     def _response_json(self):
         return self.http_response.json()
 
     @property
     def data(self):
-        return self._response_json()['data']
+        return self._response_json()["data"]
 
     @property
     def errors(self):
-        return self._response_json()['errors']
+        return self._response_json()["errors"]
