@@ -8,8 +8,7 @@ from .transform_type import transform_type
 
 
 class ModuleCfg:
-
-    def __init__(self, defaults, *, module_name='unidentified module'):
+    def __init__(self, defaults, *, module_name="unidentified module"):
         self._defaults = {k.lower(): v for k, v in defaults.items()}
         self._env = dependency(os).environ
         self._module_name = module_name
@@ -23,25 +22,22 @@ class ModuleCfg:
         if 1 == count:
             return matches[0]
         raise InvalidConfiguration(
-            'Found more than one environment variable that could '
-            'match "%s" (case insensitive)' % name)
+            "Found more than one environment variable that could " 'match "%s" (case insensitive)' % name
+        )
 
     def __getitem__(self, name):
         lc_name = name.lower()
         if lc_name not in self._defaults.keys():
             raise InvalidConfiguration(
                 'Refusing to use "%s" from the environment '
-                'because it was not defined in a module configuration file '
-                'for %s'
-                % (name, self._module_name))
+                "because it was not defined in a module configuration file "
+                "for %s" % (name, self._module_name)
+            )
         default = self._defaults[lc_name]
         from_env = self._from_env(name)
-        return default if from_env is None else transform_type(
-            key=name, val=from_env, new_type=type(default))
+        return default if from_env is None else transform_type(key=name, val=from_env, new_type=type(default))
 
     def to_dict(self):
-        return {
-            name: self[name]
-            for name in self._defaults.keys()}
+        return {name: self[name] for name in self._defaults.keys()}
 
     __getattr__ = __getitem__
