@@ -3,9 +3,9 @@ from traceback import TracebackException
 
 def indent(s):
     if s:
-        spaces = 4 if s.startswith('File') or s.startswith('Traceback') else 8
-        return ''.join([' ' for n in range(spaces)]) + s
-    return ''
+        spaces = 4 if s.startswith("File") or s.startswith("Traceback") else 8
+        return "".join([" " for n in range(spaces)]) + s
+    return ""
 
 
 def format_exception(e):
@@ -15,7 +15,7 @@ def format_exception(e):
     tb = TracebackException.from_exception(e)
     stack = []
     for raw in tb.format():
-        stack += [s.strip() for s in raw.split('\n')]
-    msg = '(%s) %s' % ((type(e).__name__, e))
+        stack += [s.strip() for s in raw.split("\n")]
+    msg = "(%s) %s" % ((type(e).__name__, e))
     trace = filter(lambda s: s, map(indent, [s for s in stack[:-1]]))
-    return '{}\n'.format(msg) + '\n'.join(trace)
+    return "{}\n".format(msg) + "\n".join(trace)
