@@ -1,11 +1,11 @@
 def join(one, two):
     if not one:
         return two
-    if one.endswith('/') and two.startswith('/'):
+    if one.endswith("/") and two.startswith("/"):
         return one + two[1:]
-    if one.endswith('/') or two.startswith('/'):
+    if one.endswith("/") or two.startswith("/"):
         return one + two
-    return '%s/%s' % (one, two)
+    return "%s/%s" % (one, two)
 
 
 def url_append(*parts):
@@ -14,7 +14,7 @@ def url_append(*parts):
      1. Does not eliminate characters when slashes are present
      2. Joins an arbitrary number of parts
     """
-    whole = ''
+    whole = ""
     for part in [p for p in parts if p]:
         whole = join(whole, part)
     return whole
